package com.fuyuanshen.app.service;

import com.fuyuanshen.app.domain.vo.AppPersonnelInfoVo;
import com.fuyuanshen.app.domain.bo.AppPersonnelInfoBo;
import com.fuyuanshen.common.mybatis.core.page.TableDataInfo;
import com.fuyuanshen.common.mybatis.core.page.PageQuery;
import com.fuyuanshen.equipment.domain.dto.AppDeviceBo;

import java.util.Collection;
import java.util.List;

/**
 * 人员信息登记Service接口
 *
 * @author Lion Li
 * @date 2025-07-02
 */
public interface IAppPersonnelInfoService {

    /**
     * 查询人员信息登记
     *
     * @param id 主键
     * @return 人员信息登记
     */
    AppPersonnelInfoVo queryById(Long id);

    /**
     * 分页查询人员信息登记列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 人员信息登记分页列表
     */
    TableDataInfo<AppPersonnelInfoVo> queryPageList(AppPersonnelInfoBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的人员信息登记列表
     *
     * @param bo 查询条件
     * @return 人员信息登记列表
     */
    List<AppPersonnelInfoVo> queryList(AppPersonnelInfoBo bo);

    /**
     * 新增人员信息登记
     *
     * @param bo 人员信息登记
     * @return 是否新增成功
     */
    Boolean insertByBo(AppPersonnelInfoBo bo);

    /**
     * 修改人员信息登记
     *
     * @param bo 人员信息登记
     * @return 是否修改成功
     */
    Boolean updateByBo(AppPersonnelInfoBo bo);

    /**
     * 校验并批量删除人员信息登记信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);

    boolean registerPersonInfo(AppPersonnelInfoBo bo);
}
