/*
 *  Copyright 2019-2025 Zheng Jie
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.fuyuanshen.customer.domain.query;

import com.fuyuanshen.common.mybatis.core.domain.BaseEntity;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serializable;
import java.sql.Timestamp;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * @author Zheng Jie
 * @date 2018-11-23
 */
@Data
public class UserQueryCriteria extends BaseEntity {

    @Schema(name = "ID")
    private Long id;

    @Schema(name = "ids")
    private Set<Long> ids;

    @Schema(name = "pid")
    private Long pid;

    @Schema(name = "多个ID")
    private Set<Long> deptIds = new HashSet<>();

    @Schema(name = "模糊查询")
    private String blurry;

    @Schema(name = "是否启用")
    private Boolean enabled;

    /**
     * 帐号状态（0正常 1停用）
     */
    @Schema(name = "帐号状态（0正常 1停用）")
    private String status;

    @Schema(name = "部门ID")
    private Long deptId;

    // @Schema(name = "创建时间")
    // // private List<Timestamp> createTime;

    @Schema(name = "页码", example = "1")
    private Integer pageNum = 1;

    @Schema(name = "每页数据量", example = "10")
    private Integer pageSize = 10;

    @Schema(name = "偏移量", hidden = true)
    private long offset;

    /**
     * 用户类型
     * 0 app
     * 1 小程序
     */
    @Schema(name = "用户类型 0 app 1 小程序")
    private Integer userType;

    /**
     * 账号
     */
    @Schema(name = "APP/小程序账号")
    private String username;

    /**
     * 客户名称
     */
    @Schema(name = "客户名称")
    private String customerName;

}
